( function( $ ) {
	var fileFrame,
		feedTimeout = null,
		seasonTimeout = null,
		imgUploadText = window.podcastplayerImageUploadText || {},
		ppjsAdmin = window.ppjsAdmin || {},
		$document = $( document );

	$document.on( 'click', '.podcast-player-widget-img-uploader', function( event ) {
		var _this = $( this );
		event.preventDefault();

		// Create the media frame.
		fileFrame = wp.media.frames.fileFrame = wp.media({
			title: imgUploadText.uploader_title,
			button: {
				text: imgUploadText.uploader_button_text
			},
			multiple: false  // Set to true to allow multiple files to be selected
		});

		// When an image is selected, run a callback.
		fileFrame.on( 'select', function() {

			// We set multiple to false so only get one image from the uploader
			var attachment  = fileFrame.state().get( 'selection' ).first().toJSON(),
				imgUrl      = attachment.url,
				imgId       = attachment.id,
				featuredImg = document.createElement( 'img' );

			featuredImg.src       = imgUrl;
			featuredImg.className = 'custom-widget-thumbnail';
			_this.html( featuredImg );
			_this.addClass( 'has-image' );
			_this.nextAll( '.podcast-player-widget-img-id' ).val( imgId ).trigger( 'change' );
			_this.nextAll( '.podcast-player-widget-img-instruct, .podcast-player-widget-img-remover' ).removeClass( 'podcast-player-hidden' );
		});

		// Finally, open the modal
		fileFrame.open();
	});

	$document.on( 'click', '.podcast-player-widget-img-remover', function( event ) {
		event.preventDefault();
		$( this ).prevAll( '.podcast-player-widget-img-uploader' ).html( imgUploadText.set_featured_img ).removeClass( 'has-image' );
		$( this ).prev( '.podcast-player-widget-img-instruct' ).addClass( 'podcast-player-hidden' );
		$( this ).next( '.podcast-player-widget-img-id' ).val( '' ).trigger( 'change' );
		$( this ).addClass( 'podcast-player-hidden' );
	});

	$document.on( 'click', '.pp-settings-toggle', function( event ) {
		var _this = $( this );
		var content = _this.next( '.pp-settings-content' );
		event.preventDefault();
		content.slideToggle('fast');
		_this.toggleClass( 'toggle-active' );

		if (_this.hasClass('pp-filter-toggle')) {
			if (content.find('.d-episode input[type="checkbox"]').is(':checked')) {
				content.find('.pp-episodes input[type="checkbox"]').attr("disabled", true);
			}
			if (content.find('.d-season input[type="checkbox"]').is(':checked')) {
				content.find('.pp-seasons input[type="checkbox"]').attr("disabled", true);
			}
		}
	});

	$(document).on( 'ready widget-added widget-updated', function(event, widget) {
		var params = { 
			change: function(e, ui) {
				$( e.target ).val( ui.color.toString() );
				$( e.target ).trigger('change'); // enable widget "Save" button
			},
		} 
		$('.pp-color-picker').not('[id*="__i__"]').wpColorPicker( params );
	});

	$('#widgets-right').on('change', 'select.podcast-player-pp-display-style', function() {
		var _this = $(this);
		var style = _this.val();
		var wrapper = _this.closest('.widget-content');
		var hdefault = wrapper.find('.pp_header_default');
		var ldefault = wrapper.find('.pp_list_default');
		var excerpt = wrapper.find('.pp_excerpt_length');
		var gridCol = wrapper.find('.pp_grid_columns');
		var asRatio = wrapper.find('.pp_aspect_ratio');
		var cropMet = wrapper.find('.pp_crop_method');
		var txtColor = wrapper.find('.pp_txtcolor');
		var excerptSupport = ['lv1', 'gv1'];
		var thumbSupport = ['lv1', 'lv2', 'gv1'];
		var gridSupport = ['gv1'];
		var txtColorSupport = ['lv1', 'lv2', 'lv3', 'gv1'];
		var aspectRatio;

		if (!style || 'legacy' === style) {
			hdefault.show();
		} else {
			hdefault.hide();
		}

		if (!style || 'legacy' === style) {
			ldefault.show();
		} else {
			ldefault.hide();
		}

		if (excerptSupport.includes(style)) {
			excerpt.show();
		} else {
			excerpt.hide();
		}

		if (txtColorSupport.includes(style)) {
			txtColor.show();
		} else {
			txtColor.hide();
		}

		if (gridSupport.includes(style)) {
			gridCol.show();
		} else {
			gridCol.hide();
		}

		if (thumbSupport.includes(style)) {
			asRatio.show();
			aspectRatio = wrapper.find('select.podcast-player-pp-aspect-ratio');
			if (aspectRatio.length && aspectRatio.val()) {
				cropMet.show();
			}
		} else {
			asRatio.hide();
			cropMet.hide();
		}
	});

	$('#widgets-right').on('change', 'select.podcast-player-pp-aspect-ratio', function() {
		var _this = $(this);
		var wrapper = _this.closest('.widget-content');
		var cropMet = wrapper.find('.pp_crop_method');
		if (_this.val()) {
			cropMet.show();
		} else {
			cropMet.hide();
		}
	});

	$('#widgets-right').on('change', 'select.podcast-player-pp-start-when', function() {
		var _this = $(this);
		var val = _this.val();
		var wrapper = _this.closest('.widget-content');
		var customTime = wrapper.find('.pp_start_time');
		if (val && 'custom' === val) {
			customTime.show();
		} else {
			customTime.hide();
		}
	});

	$('#widgets-right').on('change', '.pp_hide_header input[type="checkbox"]', function() {
		var _this = $(this);
		var parent = _this.parent();
		var sibs = parent.nextAll('.pp_hide_cover, .pp_hide_title, .pp_hide_description, .pp_hide_subscribe');
		if (_this.is(':checked')) {
			sibs.hide();
		} else {
			sibs.show();
		}
	});

	$('#widgets-right').on('change', 'select.podcast-player-pp-fetch-method', function() {
		var _this = $(this);
		var wrapper = _this.closest('.widget-content');
		var tax = wrapper.find('select.podcast-player-pp-taxonomy');
		wrapper.find('.toggle-active').removeClass('toggle-active');
		wrapper.find('.pp-settings-content').hide();
		if ('feed' === _this.val()) {
			wrapper.find('.feed_url').show();
			wrapper.find('.pp_post_type, .pp_taxonomy, .pp_terms').hide();
			wrapper.find('.pp_podtitle').hide();
			wrapper.find('.pp-settings-toggle, .pp_hide_content, .pp_seasons, .pp_episodes, .pp_display_style').show();
			wrapper.find('.pp_audiosrc, .pp_audiotitle, .pp_audiolink, .pp_ahide_download, .pp_ahide_social, .pp-lshow-toggle, .pp-linfo-toggle').hide();
			tax.val('');
			wrapper.find('.pp_terms-checklist input:checkbox').removeAttr('checked');
		} else if ( 'post' === _this.val() ) {
			wrapper.find('.feed_url').hide();
			wrapper.find('.pp_post_type, .pp_taxonomy, .pp-settings-toggle, .pp_podtitle, .pp_display_style').show();
			wrapper.find('.pp_audiosrc, .pp_audiotitle, .pp_audiolink, .pp_ahide_download, .pp_ahide_social, .pp_hide_content, .pp_seasons, .pp_episodes, .pp-lshow-toggle, .pp-linfo-toggle').hide();
		} else if ( 'link' === _this.val() ) {
			wrapper.find('.feed_url').hide();
			wrapper.find('.pp_post_type, .pp_taxonomy, .pp_terms, .pp_seasons, .pp_episodes, .pp-info-toggle, .pp-filter-toggle, .pp-show-toggle, .pp_display_style').hide();
			wrapper.find('.pp_audiosrc, .pp_audiotitle, .pp_audiolink, .pp_ahide_download, .pp_ahide_social, .pp-lshow-toggle, .pp-linfo-toggle').show();
			tax.val('');
			wrapper.find('.pp_terms-checklist input:checkbox').removeAttr('checked');
		}
	});

	$('#widgets-right').on('change', 'select.podcast-player-pp-post-type', function() {
		var _this = $(this);
		var postType = _this.val();
		var wrapper = _this.closest('.widget-content');
		var taxonomy = wrapper.find('.podcast-player-pp-taxonomy');
		wrapper.find('.pp_terms').hide();
		wrapper.find('.pp_terms-checklist input:checkbox').removeAttr('checked');
		taxonomy.find( 'option' ).hide();
		taxonomy.find( '.' + postType ).show();
		taxonomy.find( '.always-visible' ).show();
		taxonomy.val('');
	});

	$('#widgets-right').on('change', 'select.podcast-player-pp-taxonomy', function() {
		var _this = $(this);
		var wrapper = _this.closest('.widget-content');
		var terms = wrapper.find('.pp_terms');
		wrapper.find('.pp_terms-checklist input:checkbox').removeAttr('checked');
		if ( _this.val() ) {
			terms.show();
			terms.find( '.pp_terms-checklist li' ).hide();
			terms.find( '.pp_terms-checklist .' + _this.val() ).show();
		} else {
			terms.hide();
		}
	});

	$('#widgets-right').on('input', '.feed_url input', function() {
		var _this = $(this);
		var url = _this.val();
		var wrapper = _this.closest('.widget-content');
		fetchFeedEpisodes(url, wrapper);
		fetchFeedSeasons(url, wrapper);
	});

	$('#widgets-right').on('change', 'select.podcast-player-pp-fetch-method', function() {
		var _this = $(this);
		var wrapper = _this.closest('.widget-content');
		var url;
		if ('feed' === _this.val()) {
			url = $.trim(wrapper.find('.feed_url input').val());
			fetchFeedEpisodes(url, wrapper);
			fetchFeedSeasons(url, wrapper);
		} else if ('post' === _this.val()) {
			fetchPostEpisodes(wrapper);
			wrapper.find('.pp-seasons-list').hide();
		} else {
			wrapper.find('.pp-episodes-list').hide();
			wrapper.find('.pp-seasons-list').hide();
		}
	});

	$('#widgets-right').on('change', 'select.podcast-player-pp-post-type, select.podcast-player-pp-taxonomy, select.podcast-player-sortby, .pp_terms-checklist input[type="checkbox"], .filterby input', function() {
		var _this = $(this);
		var wrapper = _this.closest('.widget-content');
		fetchPostEpisodes(wrapper);
	});

	$('#widgets-right').on('change', '.d-episode input[type="checkbox"]', function() {
		var _this = $(this);
		var wrapper = _this.closest('.widget-content');
		if (_this.is(':checked')) {
			wrapper.find('.pp-episodes input[type="checkbox"]').attr("disabled", true).prop("checked", false);
		} else {
			wrapper.find('.pp-episodes input[type="checkbox"]').attr("disabled", false);
		}
	});

	$('#widgets-right').on('change', '.d-season input[type="checkbox"]', function() {
		var _this = $(this);
		var wrapper = _this.closest('.widget-content');
		if (_this.is(':checked')) {
			wrapper.find('.pp-seasons input[type="checkbox"]').attr("disabled", true).prop("checked", false);
		} else {
			wrapper.find('.pp-seasons input[type="checkbox"]').attr("disabled", false);
		}
	});

	function fetchPostEpisodes(wrapper) {
		var postType = wrapper.find('select.podcast-player-pp-post-type').val(),
			taxonomy = wrapper.find('select.podcast-player-pp-taxonomy').val(),
			sortby = wrapper.find('select.podcast-player-sortby').val(),
			filterby = wrapper.find('.filterby input').val(),
			terms = [];
		$.each(wrapper.find('.pp_terms-checklist input[type="checkbox"]:checked'), function() {
			terms.push($(this).val());
		});

		data = {
			action  : 'pp_post_episodes_list',
			security: ppjsAdmin.security,
			postType: postType,
			taxonomy: taxonomy,
			terms: terms,
			sortby: sortby,
			filterby: filterby,
		}

		wrapper.find('li.pp-episodes').remove();

		// Let's get next set of episodes.
		jQuery.ajax( {
			url: ppjsAdmin.ajaxurl,
			data: data,
			type: 'POST',
			timeout: 4000,
			success: response => {
				var details = jQuery.parseJSON( response );
				if (jQuery.isEmptyObject(details)) {
					console.log('PP Error: Empty object received');
					wrapper.find('.pp-episodes-list').hide();
				} else {
					if (details.episodes) {
						episodeMarkup(wrapper, details.episodes);
						wrapper.find('.pp-episodes-list').show();
					} else if (details.error) {
						console.log(details.error);
						wrapper.find('.pp-episodes-list').hide();
					}
				}
			},
			error: (jqXHR, testStatus, errorThrown) => {
				console.log(errorThrown);
				wrapper.find('.pp-episodes-list').hide();
			}
		} );
	}

	function fetchFeedEpisodes(url, wrapper) {
		var data;
		clearTimeout(feedTimeout);
		feedTimeout = setTimeout(function() {
			url = $.trim( url );
			if ( url ) {
				wrapper.find('li.pp-episodes').remove();
				data = {
					action  : 'pp_episodes_list',
					security: ppjsAdmin.security,
					feedUrl : url,
				}
				// Let's get next set of episodes.
				jQuery.ajax( {
					url: ppjsAdmin.ajaxurl,
					data: data,
					type: 'POST',
					timeout: 10000,
					success: response => {
						var details = jQuery.parseJSON( response );
						if (jQuery.isEmptyObject(details)) {
							console.log('PP Error: Empty object received');
							wrapper.find('.pp-episodes-list').hide();
						} else {
							if (details.episodes) {
								episodeMarkup(wrapper, details.episodes);
								wrapper.find('.pp-episodes-list').show();
							} else if (details.error) {
								console.log(details.error);
								wrapper.find('.pp-episodes-list').hide();
							}
						}
					},
					error: (jqXHR, testStatus, errorThrown) => {
						console.log(errorThrown);
						wrapper.find('.pp-episodes-list').hide();
					}
				} );
			} else {
				wrapper.find('.pp-episodes-list').hide();
			}
		}.bind(this), 500);
	}

	function fetchFeedSeasons(url, wrapper) {
		var data;
		clearTimeout(seasonTimeout);
		seasonTimeout = setTimeout(function() {
			url = $.trim( url );
			if ( url ) {
				wrapper.find('li.pp-seasons').remove();
				data = {
					action  : 'pp_seasons_list',
					security: ppjsAdmin.security,
					feedUrl : url,
				}
				// Let's get next set of episodes.
				jQuery.ajax( {
					url: ppjsAdmin.ajaxurl,
					data: data,
					type: 'POST',
					timeout: 10000,
					success: response => {
						var details = jQuery.parseJSON( response );
						if (jQuery.isEmptyObject(details)) {
							console.log('PP Error: Empty object received');
							wrapper.find('.pp-seasons-list').hide();
						} else {
							if (details.seasons) {
								seasonMarkup(wrapper, details.seasons);
								wrapper.find('.pp-seasons-list').show();
							} else if (details.error) {
								wrapper.find('.pp-seasons-list').hide();
								console.log(details.error);
							}
						}
					},
					error: (jqXHR, testStatus, errorThrown) => {
						console.log(errorThrown);
						wrapper.find('.pp-seasons-list').hide();
					}
				} );
			} else {
				wrapper.find('.pp-seasons-list').hide();
			}
		}.bind(this), 500);
	}

	function episodeMarkup(wrapper, episodes) {
		var container, mould, cbox;
		wrapper.find('.d-episode input[type="checkbox"]').prop("checked", true);
		container = wrapper.find('.pp_elist-checklist ul');
		mould = wrapper.find('li.d-episode').clone();
		cbox  = mould.find('input[type="checkbox"]');
		mould.removeClass('d-episode').addClass('pp-episodes');
		if (cbox.is(':checked')) {
			cbox.attr("disabled", true).prop("checked", false);
		}
		$.each( episodes, function(id, label) {
			var episode = mould.clone();
			episode.find('input[type="checkbox"]').val(id);
			episode.find('.cblabel').html(label);
			container.append(episode);
		} );
	}

	function seasonMarkup(wrapper, seasons) {
		var container, mould, cbox;
		wrapper.find('.d-season input[type="checkbox"]').prop("checked", true);
		container = wrapper.find('.pp_slist-checklist ul');
		mould = wrapper.find('li.d-season').clone();
		cbox  = mould.find('input[type="checkbox"]');
		mould.removeClass('d-season').addClass('pp-seasons');
		if (cbox.is(':checked')) {
			cbox.attr("disabled", true).prop("checked", false);
		}
		$.each( seasons, function(id, label) {
			var season = mould.clone();
			season.find('input[type="checkbox"]').val(id);
			season.find('.cblabel').html(label);
			container.append(season);
		} );
	}
} )( jQuery );
