import FetchFilters from './fetchFilters';
import vars from './variables';

class FetchMethod {

	/**
	 * Manage Feed editor options.
	 * 
	 * @since 3.3
	 * 
	 * @param {string} id Podcast player ID. 
	 */
	constructor() {
		// Run methods.
		this.events();
	}

	// Event handling.
	events() {
		const _this = this;

		jQuery('#widgets-right, #elementor-editor-wrapper').on(
			'change',
			'.podcast-player-pp-fetch-method',
			function() {
				_this.changeFetchMethod(jQuery(this));
			}
		);
	}

	/**
	 * Change in podcast fech method.
	 * 
	 * @since 3.3.0
	 * 
	 * @param Obj obj
	 */
	changeFetchMethod(obj) {
		const wrapper = obj.closest('.widget-content');
		const fetchMethod = obj.val();
		const commonHide = [
			'.pp-settings-content',
			'.pp_terms',
		];
		const feedSpecific = [
			'.feed_url',
			'.pp_hide_content',
			'.pp_slist',
			'.pp_catlist',
		];
		const postSpecific = [
			'.pp_post_type',
			'.pp_taxonomy',
			'.pp_podtitle',
		];
		const linkSpecific = [
			'.pp_audiosrc',
			'.pp_audiotitle',
			'.pp_audiolink',
			'.pp_ahide_download',
			'.pp_ahide_social',
			'.pp-lshow-toggle',
			'.pp-linfo-toggle',
		];
		const linkHide = [
			'.pp_display_style',
			'.pp_elist',
			'.pp-info-toggle',
			'.pp-filter-toggle',
			'.pp-show-toggle',
		];

		// Common Actions.
		wrapper.find('select.podcast-player-pp-taxonomy').val('');
		wrapper.find('.toggle-active').removeClass('toggle-active');
		wrapper.find(commonHide.join(',')).hide();

		// Fetch Method Specific actions.
		if ('feed' === fetchMethod) {
			wrapper.find(feedSpecific.join(',')).show();
			wrapper.find(postSpecific.join(',')).hide();
			wrapper.find(linkSpecific.join(',')).hide();
			wrapper.find(linkHide.join(',')).show();
		} else if ('post' === fetchMethod) {
			wrapper.find(feedSpecific.join(',')).hide();
			wrapper.find(postSpecific.join(',')).show();
			wrapper.find(linkSpecific.join(',')).hide();
			wrapper.find(linkHide.join(',')).show();
		} else if ('link' === fetchMethod) {
			wrapper.find(feedSpecific.join(',')).hide();
			wrapper.find(postSpecific.join(',')).hide();
			wrapper.find(linkSpecific.join(',')).show();
			wrapper.find(linkHide.join(',')).hide();
		}

		// Filter Checkboxes.
		if ('feed' === fetchMethod || 'post' === fetchMethod) {
			clearTimeout(vars.ajaxtimeout);
			vars.ajaxtimeout = setTimeout( () => {
				new FetchFilters(wrapper, fetchMethod, true);
			}, 500 );
		}
	}
}

export default FetchMethod;
